@@ -15,19 +15,65 @@ msgid(SPLASH_TITLE)
 msgstr("Welcome to the newer uTox!")
 
 msgid(SPLASH_TEXT)
-msgstr("You have just upgraded to version 0.17.0! Release name: bork bork")
+msgstr("You have just upgraded to version 0.17.1! Release name: \"Don't 🌟e at my 😬!\"")
 
 msgid(CHANGE_LOG_TITLE)
-msgstr("Changes in v0.17.0")
+msgstr("Changes in v0.17.1")
 
 msgid(CHANGE_LOG_TEXT)
 msgstr(
 "\n  IMPORTANT NOTE FOR WINDOWS USERS\n"
-"    There is currently an issue with the updater where it won't work with some .exe names.\n"
-"    To be sure that it works and autoupdates, you have to rename the .exe to \"uTox.exe\"\n"
-"    and enable it in the settings.\n"
+"    Autoupdates are no longer provided.\n"
 "\n"
 "  Features:\n"
+"    Add `--allow-root` option: Now you can't run uTox as root by accident\n"
+"    Add right click menu to Xlib\n"
+"    Add support for loading groupchats\n"
+"    More *BSD support! (FreeBSD, NetBSD, OpenBSD, DragonFlyBSD) (Thanks, mazocomp!)\n"
+"    Groupchat creation screen implemented\n"
+"\n"
+"  Fixes:\n"
+"    Fix a crash when changing to a video input device that fails to init\n"
+"    Fix a friendlist bug related to the Tox profile having no friends and groups\n"
+"    Don't flip video preview button status if preview fails\n"
+"    Xlib: Clean up zombies if `xdg-open` is not installed\n"
+"    Add border to QR code to make it actually readable to QR code scanners\n"
+"    Fix file transfer text\n"
+"    Prevent a crash related to having too many friends\n"
+"    Fix crash related to dropdowns\n"
+"    Fix ignoring friend requests\n"
+"    Close dropdowns on changing tabs\n"
+"    Fix crash on startup related to QR code (Thanks, ColumPaget!)\n"
+"    Fix group settings layout\n"
+"    Fix a crash related to Tox savedata being too large\n"
+"    Fix two possible memory leaks\n"
+"    Fix a crash related to text undo in message input field (Thanks, cyisfor!)\n"
+"    Fix a crash related to the password input field\n"
+"    Fix crash related to FPS value input field\n"
+"    Fix selection bug: Selection on double-click doesn't leak into neighbouring line anymore\n"
+"    Fix HOME key\n"
+"    Fix END key and make ctrl+shift+end work\n"
+"    Sort languages enum by their native names alphabetically\n"
+"    Move Language setting from \"Profile\" to \"User Interface\" tab\n"
+"    Updated translations:\n"
+"      - German\n"
+"      - English\n"
+"      - Polish\n"
+"      - Swedish (Thanks, jony0008!)\n"
+"      - Hungarian (Thanks, baloo79!)\n"
+"\n"
+"  Development:\n"
+"    Try to upgrade travis\n"
+"    Travis win64 make cmake command explicit\n"
+"    Disable incorrect updater test\n"
+"    Auto 'clone' STB with cmake\n"
+"    Make uTox reproducible (Thanks, bmwiedemann!)\n"
+"    Some fixes for *BSD systems (Thanks, mazocomp!)\n"
+"      - Enable tests by default\n"
+"      - Update build instructions and add instructions for NetBSD and DragonFlyBSD\n"
+"      - other build system fixes\n"
+"\nv0.17.0\n"
+"  Features:\n"
 "    Toxcore 0.2.x. support!\n"
 "    Settings are now stored in a human-readable .ini file.\n"
 "    We now support Tox URIs.\n"
@@ -343,11 +389,14 @@ msgstr("Export Chatlog as plain text")
 msgid(GROUPCHAT_JOIN_AUDIO)
 msgstr("Join audio chat")
 
+msgid(GROUP_CREATE_WITH_AUDIO)
+msgstr("Enable Audio")
+
 msgid(GROUP_CREATE_TEXT)
-msgstr("Create a text group chat")
+msgstr("Create a text-chat group")
 
 msgid(GROUP_CREATE_VOICE)
-msgstr("Create a group chat with voice")
+msgstr("Create a voice-chat group")
 
 msgid(CREATEGROUPCHAT)
 msgstr("Create Groupchat")
@@ -583,10 +632,10 @@ msgid(NETWORK)
 msgstr("Network")
 
 msgid(IPV6)
-msgstr("IPv6:")
+msgstr("IPv6")
 
 msgid(UDP)
-msgstr("UDP:")
+msgstr("UDP")
 
 msgid(PROXY)
 msgstr("Proxy (SOCKS 5)")
@@ -616,13 +665,13 @@ msgid(START_IN_TRAY)
 msgstr("Start In Tray")
 
 msgid(SHOW_QR)
-msgstr("Show QR")
+msgstr("Show QR code")
 
 msgid(HIDE_QR)
-msgstr("Hide QR")
+msgstr("Hide QR code")
 
 msgid(SAVE_QR)
-msgstr("Save QR")
+msgstr("Save QR code")
 
 msgid(COPY_TOX_ID)
 msgstr("Copy as text")
@@ -804,6 +853,9 @@ msgstr("Show")
 msgid(HIDE)
 msgstr("Hide")
 
+msgid(EXIT)
+msgstr("Exit")
+
 msgid(VIDEO_IN_NONE)
 msgstr("None")
 
@@ -823,7 +875,7 @@ msgid(CONTACT_SEARCH_ADD_HINT)
 msgstr("Search/Add Friends")
 
 msgid(PROXY_EDIT_HINT_IP)
-msgstr("IP")
+msgstr("IP address")
 
 msgid(PROXY_EDIT_HINT_PORT)
 msgstr("Port")
