@@ -257,6 +257,7 @@ panel_friend_request = {
     .drawfunc = draw_friend_request,
     .child = (PANEL*[]) {
         (PANEL*)&button_accept_friend,
+        (PANEL*)&button_ignore_friend,
         NULL
     }
 },
@@ -428,6 +429,17 @@ static void button_accept_friend_on_mup(void) {
     panel_friend_request.disabled = true;
 }
 
+static void button_ignore_friend_on_mup(void){
+    FREQUEST *req = flist_get_frequest();
+    if (!req) {
+        LOG_ERR("Friend", "Could not get selected friend request");
+        return;
+    }
+
+    flist_delete_sitem();
+    panel_friend_request.disabled = true;
+}
+
 static void button_menu_update(BUTTON *b) {
     b->c1  = COLOR_BKGRND_MENU;
     b->c2  = COLOR_BKGRND_MENU_HOVER;
@@ -566,12 +578,33 @@ BUTTON button_send_screenshot = {
 };
 
 BUTTON button_accept_friend = {
+    .panel = {
+        .type = PANEL_BUTTON,
+        .x = -140,
+        .y = -80,
+        .width = _BM_SBUTTON_WIDTH,
+        .height = _BM_SBUTTON_HEIGHT,
+    },
     .bm_fill         = BM_SBUTTON,
     .button_text = {.i18nal = STR_ADD },
     .update      = button_setcolors_success,
     .on_mup      = button_accept_friend_on_mup,
 };
 
+BUTTON button_ignore_friend = {
+    .panel = {
+        .type = PANEL_BUTTON,
+        .x = -80,
+        .y = -80,
+        .width = _BM_SBUTTON_WIDTH,
+        .height = _BM_SBUTTON_HEIGHT,
+    },
+    .bm_fill     = BM_SBUTTON,
+    .button_text = {.i18nal = STR_IGNORE},
+    .update     = button_setcolors_danger,
+    .on_mup     = button_ignore_friend_on_mup,
+};
+
 static void switchfxn_autoaccept_ft(void) {
     FRIEND *f = flist_get_friend();
     if (f) {
@@ -582,34 +615,6 @@ static void switchfxn_autoaccept_ft(void) {
 
 #include "../ui/switch.h"
 
-static void switch_set_colors(UISWITCH *s) {
-    if (s->switch_on) {
-        s->bg_color    = COLOR_BTN_SUCCESS_BKGRND;
-        s->sw_color    = COLOR_BTN_SUCCESS_TEXT;
-        s->press_color = COLOR_BTN_SUCCESS_BKGRND_HOVER;
-        s->hover_color = COLOR_BTN_SUCCESS_BKGRND_HOVER;
-    } else {
-        s->bg_color    = COLOR_BTN_DISABLED_BKGRND;
-        s->sw_color    = COLOR_BTN_DISABLED_FORGRND;
-        s->hover_color = COLOR_BTN_DISABLED_BKGRND_HOVER;
-        s->press_color = COLOR_BTN_DISABLED_BKGRND_HOVER;
-    }
-}
-
-static void switch_set_size(UISWITCH *s) {
-    s->toggle_w   = BM_SWITCH_TOGGLE_WIDTH;
-    s->toggle_h   = BM_SWITCH_TOGGLE_HEIGHT;
-    s->icon_off_w = BM_FB_WIDTH;
-    s->icon_off_h = BM_FB_HEIGHT;
-    s->icon_on_w  = BM_FB_WIDTH;
-    s->icon_on_h  = BM_FB_HEIGHT;
-}
-
-static void switch_update(UISWITCH *s) {
-    switch_set_colors(s);
-    switch_set_size(s);
-}
-
 UISWITCH switch_friend_autoaccept_ft = {
     .style_outer    = BM_SWITCH,
     .style_toggle   = BM_SWITCH_TOGGLE,
@@ -627,8 +632,9 @@ static void edit_add_new_contact(EDIT *UNUSED(edit)) {
 
 static char e_friend_pubkey_str[TOX_PUBLIC_KEY_SIZE * 2];
 EDIT edit_friend_pubkey = {
+    // .length == .data_size, because .data is not \0-terminated
     .length            = sizeof e_friend_pubkey_str,
-    .maxlength         = sizeof e_friend_pubkey_str,
+    .data_size         = sizeof e_friend_pubkey_str,
     .data              = e_friend_pubkey_str,
     .readonly          = true,
     .noborder          = false,
@@ -650,7 +656,7 @@ static void edit_friend_alias_onenter(EDIT *UNUSED(edit)) {
 
 static char e_friend_alias_str[128];
 EDIT edit_friend_alias = {
-    .maxlength   = sizeof e_friend_alias_str - 1,
+    .data_size   = sizeof e_friend_alias_str,
     .data        = e_friend_alias_str,
     .onenter     = edit_friend_alias_onenter,
     .onlosefocus = edit_friend_alias_onenter,
@@ -661,7 +667,7 @@ EDIT edit_friend_alias = {
 
 static char e_add_new_friend_id_data[TOX_ADDRESS_SIZE * 4];
 EDIT edit_add_new_friend_id = {
-    .maxlength = sizeof e_add_new_friend_id_data - 1,
+    .data_size = sizeof e_add_new_friend_id_data,
     .data      = e_add_new_friend_id_data,
     .onenter   = edit_add_new_contact,
 };
@@ -677,7 +683,7 @@ EDIT edit_add_new_friend_msg = {
     .multiline = 1,
     .scroll    = &e_add_new_friend_msg_scroll,
     .data      = e_add_new_friend_msg_data,
-    .maxlength = sizeof e_add_new_friend_msg_data - 1,
+    .data_size = sizeof e_add_new_friend_msg_data,
     .empty_str = {.i18nal = STR_DEFAULT_FRIEND_REQUEST_MESSAGE },
 };
 
@@ -752,7 +758,7 @@ SCROLLABLE e_chat_msg_friend_scroll = {
 static char e_chat_msg_friend_data[65535];
 EDIT edit_chat_msg_friend = {
     .data        = e_chat_msg_friend_data,
-    .maxlength   = sizeof e_chat_msg_friend_data - 1,
+    .data_size   = sizeof e_chat_msg_friend_data,
     .multiline   = true,
     .onenter     = e_chat_msg_onenter,
     .onchange    = e_chat_msg_onchange,
