@@ -149,7 +149,7 @@ static void set_callbacks(Tox *tox) {
 
 void tox_after_load(Tox *tox) {
     utox_friend_list_init(tox);
-    init_groups();
+    init_groups(tox);
 
     #ifdef ENABLE_MULTIDEVICE
     // self.group_list_count = tox_self_get_(tox);
@@ -185,8 +185,11 @@ static void write_save(Tox *tox) {
     size_t clear_length     = tox_get_savedata_size(tox);
     size_t encrypted_length = clear_length + TOX_PASS_ENCRYPTION_EXTRA_LENGTH;
 
-    uint8_t clear_data[clear_length];
-    uint8_t encrypted_data[encrypted_length];
+    uint8_t *clear_data = calloc(1, clear_length);
+    uint8_t *encrypted_data = calloc(1, encrypted_length);
+    if (!clear_data || !encrypted_data) {
+        LOG_FATAL_ERR(EXIT_FAILURE, "Toxcore", "Could not allocate memory for savedata.\n");
+    }
 
     tox_get_savedata(tox, clear_data);
 
@@ -205,6 +208,9 @@ static void write_save(Tox *tox) {
             LOG_TRACE("Toxcore", "Encrypted save data written" );
         }
     }
+
+    free(encrypted_data);
+    free(clear_data);
 }
 
 void tox_settingschanged(void) {
@@ -266,42 +272,45 @@ static int load_toxcore_save(struct Tox_Options *options) {
     uint8_t *raw_data = utox_data_load_tox(&raw_length);
 
     /* Check if we're loading a saved profile */
-    if (raw_data && raw_length) {
-        if (tox_is_data_encrypted(raw_data)) {
-            size_t   cleartext_length = raw_length - TOX_PASS_ENCRYPTION_EXTRA_LENGTH;
-            uint8_t *clear_data       = calloc(1, cleartext_length);
-            settings.save_encryption   = 1;
-            LOG_INFO("Toxcore", "Using encrypted data, trying password: ");
-
-            UTOX_ENC_ERR decrypt_err = utox_decrypt_data(raw_data, raw_length, clear_data);
-            if (decrypt_err) {
-                if (decrypt_err == UTOX_ENC_ERR_LENGTH) {
-                    LOG_WARN("Toxcore", "Password too short!\r");
-                } else if (decrypt_err == UTOX_ENC_ERR_BAD_PASS) {
-                    LOG_ERR("Toxcore", "Couldn't decrypt, wrong password?\r");
-                } else {
-                    LOG_ERR("Toxcore", "Unknown error, please file a bug report!" );
-                }
-                return -1;
-            }
-
-            if (clear_data && cleartext_length) {
-                options->savedata_type   = TOX_SAVEDATA_TYPE_TOX_SAVE;
-                options->savedata_data   = clear_data;
-                options->savedata_length = cleartext_length;
-
-                return 0;
-            }
-        } else {
-            LOG_INFO("Toxcore", "Using unencrypted save file");
-            options->savedata_type   = TOX_SAVEDATA_TYPE_TOX_SAVE;
-            options->savedata_data   = raw_data;
-            options->savedata_length = raw_length;
-            return 0;
-        }
+    if (!raw_data || !raw_length) {
+        // No save file at all, create new profile!
+        return -2;
     }
-    /* No save file at all, create new profile! */
-    return -2;
+
+    if (!tox_is_data_encrypted(raw_data)) {
+        LOG_INFO("Toxcore", "Using unencrypted save file");
+        options->savedata_type   = TOX_SAVEDATA_TYPE_TOX_SAVE;
+        options->savedata_data   = raw_data;
+        options->savedata_length = raw_length;
+        return 0;
+    }
+
+    size_t   cleartext_length = raw_length - TOX_PASS_ENCRYPTION_EXTRA_LENGTH;
+    uint8_t *clear_data       = calloc(1, cleartext_length);
+    settings.save_encryption   = 1;
+    LOG_INFO("Toxcore", "Using encrypted data, trying password: ");
+
+    UTOX_ENC_ERR decrypt_err = utox_decrypt_data(raw_data, raw_length, clear_data);
+    if (decrypt_err) {
+        if (decrypt_err == UTOX_ENC_ERR_LENGTH) {
+            LOG_WARN("Toxcore", "Password too short!\r");
+        } else if (decrypt_err == UTOX_ENC_ERR_BAD_PASS) {
+            LOG_ERR("Toxcore", "Couldn't decrypt, wrong password?\r");
+        } else {
+            LOG_ERR("Toxcore", "Unknown error, please file a bug report!" );
+        }
+        return -1;
+    }
+
+    if (!clear_data || !cleartext_length) {
+        return -1;
+    }
+
+    options->savedata_type   = TOX_SAVEDATA_TYPE_TOX_SAVE;
+    options->savedata_data   = clear_data;
+    options->savedata_length = cleartext_length;
+
+    return 0;
 }
 
 static void log_callback(Tox *UNUSED(tox), TOX_LOG_LEVEL level, const char *file, uint32_t line,
