@@ -40,6 +40,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <signal.h>
+#include <sys/wait.h>
 
 bool hidden = false;
 
@@ -94,6 +95,11 @@ void init_ptt(void) {
 
 #ifdef __linux__
 #include <linux/input.h>
+#elif defined(__DragonFly__) || defined(__FreeBSD__)
+#include <dev/misc/evdev/input.h>
+#endif
+
+#if defined(__linux__) || defined(__DragonFly__) || defined(__FreeBSD__)
 static bool linux_check_ptt(void) {
     /* First, we try for direct access to the keyboard. */
     int ptt_key = KEY_LEFTCTRL; // TODO allow user to change this...
@@ -146,7 +152,7 @@ bool check_ptt_key(void) {
         return true; /* If push to talk is disabled, return true. */
     }
 
-#ifdef __linux__
+#if defined(__linux__) || defined(__DragonFly__) || defined(__FreeBSD__)
     return linux_check_ptt();
 #else
     return bsd_check_ptt();
@@ -221,6 +227,7 @@ void openurl(char *str) {
         execlp(cmd, cmd, str, (char *)0);
         exit(127);
     }
+    waitpid(-1, NULL, WNOHANG); /* reap last child */
 }
 
 void openfilesend(void) {
@@ -696,10 +703,16 @@ int main(int argc, char *argv[]) {
     int8_t should_launch_at_startup;
     int8_t set_show_window;
     bool   skip_updater;
+    bool allow_root;
     parse_args(argc, argv,
                &skip_updater,
                &should_launch_at_startup,
-               &set_show_window);
+               &set_show_window,
+               &allow_root);
+
+    if (getuid() == 0 && !allow_root){
+        LOG_FATAL_ERR(EXIT_FAILURE, "XLIB MAIN", "You can't run uTox as root unless --allow-root is set.");
+    }
 
     // We need to parse_args before calling utox_init()
     utox_init();
@@ -834,7 +847,7 @@ int main(int argc, char *argv[]) {
     while (!shutdown) {
         XEvent event;
         XNextEvent(display, &event);
-        if (!doevent(event)) {
+        if (!doevent(&event)) {
             break;
         }
 
